@@ -35,9 +35,9 @@ from math import ceil
 
 from custodian.custodian import ErrorHandler
 from custodian.utils import backup
-from pymatgen.io.vaspio.vasp_input import Poscar, VaspInput, Incar
+from pymatgen.io.vaspio.vasp_input import Poscar, VaspInput, Incar, Kpoints
 from pymatgen.transformations.standard_transformations import \
-    PerturbStructureTransformation, SupercellTransformation
+    SupercellTransformation
 
 from pymatgen.io.vaspio.vasp_output import Vasprun, Oszicar
 from custodian.ansible.interpreter import Modder
@@ -65,7 +65,8 @@ class VaspErrorHandler(ErrorHandler):
                            "DAV"],
         "tetirr": ["Routine TETIRR needs special values"],
         "incorrect_shift": ["Could not get correct shifts"],
-        "real_optlay": ["REAL_OPTLAY: internal error"],
+        "real_optlay": ["REAL_OPTLAY: internal error",
+                        "REAL_OPT: internal ERROR"],
         "rspher": ["ERROR RSPHER"],
         "dentet": ["DENTET"],
         "too_few_bands": ["TOO FEW BANDS"],
@@ -75,10 +76,12 @@ class VaspErrorHandler(ErrorHandler):
         "pricel": ["internal error in subroutine PRICEL"],
         "zpotrf": ["LAPACK: Routine ZPOTRF failed"],
         "amin": ["One of the lattice vectors is very long (>50 A), but AMIN"],
-        "zbrent": ["ZBRENT: fatal internal in brackting"],
+        "zbrent": ["ZBRENT: fatal internal in"],
         "aliasing": ["WARNING: small aliasing (wrap around) errors must be expected"],
         "aliasing_incar": ["Your FFT grids (NGX,NGY,NGZ) are not sufficient "
-                           "for an accurate"]
+                           "for an accurate"],
+        "pssyevx": ["ERROR in subspace rotation PSSYEVX"],
+        "eddrmm": ["WARNING in EDDRMM: call to ZHEGV failed"]
     }
 
     def __init__(self, output_filename="vasp.out"):
@@ -114,7 +117,7 @@ class VaspErrorHandler(ErrorHandler):
 
     def correct(self):
         backup([self.output_filename, "INCAR", "KPOINTS", "POSCAR", "OUTCAR",
-                "vasprun.xml"])
+                "OSZICAR", "vasprun.xml"])
         actions = []
         vi = VaspInput.from_directory(".")
 
@@ -137,12 +140,26 @@ class VaspErrorHandler(ErrorHandler):
                             "action": {"_file_delete": {'mode': "actual"}}})
 
         if "zpotrf" in self.errors:
-            #Based on VASP forum's recommendation, you should
-            #decrease POTIM with this error
-            potim = float(vi["INCAR"].get("POTIM", 0.5)) / 2.0
+            # Usually caused by short bond distances. If on the first step,
+            # volume needs to be increased. Otherwise, it was due to a step
+            # being too big and POTIM should be decreased.
+            try:
+                oszicar = Oszicar("OSZICAR")
+                nsteps = len(oszicar.ionic_steps)
+            except:
+                nsteps = 0
+
+            if nsteps >= 1:
+                potim = float(vi["INCAR"].get("POTIM", 0.5)) / 2.0
+                actions.append(
+                    {"dict": "INCAR",
+                     "action": {"_set": {"ISYM": 0, "POTIM": potim}}})
+            else:
+                s = vi["POSCAR"].structure
+                s.apply_strain(0.2)
+                actions.append({"dict": "POSCAR",
+                                "action": {"_set": {"structure": s.as_dict()}}})
 
-            actions.append({"dict": "INCAR",
-                            "action": {"_set": {"ISYM": 0, "POTIM": potim}}})
             # Based on VASP forum's recommendation, you should delete the
             # CHGCAR and WAVECAR when dealing with this error.
 
@@ -156,11 +173,18 @@ class VaspErrorHandler(ErrorHandler):
             actions.append({"dict": "INCAR",
                             "action": {"_set": {"LREAL": False}}})
 
-        if self.errors.intersection(["tetirr", "incorrect_shift",
-                                     "rot_matrix"]):
+        if self.errors.intersection(["tetirr", "incorrect_shift"]):
             actions.append({"dict": "KPOINTS",
                             "action": {"_set": {"generation_style": "Gamma"}}})
 
+        if "rot_matrix" in self.errors:
+            if vi["KPOINTS"].style == Kpoints.supported_modes.Monkhorst:
+                actions.append({"dict": "KPOINTS",
+                                "action": {"_set": {"generation_style": "Gamma"}}})
+            else:
+                actions.append({"dict": "INCAR",
+                                "action": {"_set": {"ISYM": 0}}})
+
         if "amin" in self.errors:
             actions.append({"dict": "INCAR",
                             "action": {"_set": {"AMIN": "0.01"}}})
@@ -214,12 +238,13 @@ class VaspErrorHandler(ErrorHandler):
                         grid_adjusted = True
                     #Ensure that all NGX, NGY, NGZ have been checked
                     if grid_adjusted and 'NGZ' in line:
-                        actions.extend([{"dict": 
-                            "INCAR", "action": {"_set": changes_dict}},
-                            {"file": "CHGCAR", "action": 
-                             {"_file_delete": {'mode': "actual"}}},
-                            {"file": "WAVECAR","action": 
-                             {"_file_delete": {'mode': "actual"}}}])
+                        actions.extend(
+                            [{"dict": "INCAR",
+                              "action": {"_set": changes_dict}},
+                             {"file": "CHGCAR",
+                              "action": {"_file_delete": {'mode': "actual"}}},
+                             {"file": "WAVECAR",
+                              "action": {"_file_delete": {'mode': "actual"}}}])
                         break
 
         if "aliasing_incar" in self.errors:
@@ -227,10 +252,28 @@ class VaspErrorHandler(ErrorHandler):
             #aliasing error was caused by user supplied inputs
             d = {k: 1 for k in ['NGX', 'NGY', 'NGZ'] if k in vi['INCAR'].keys()}
             actions.extend([{"dict": "INCAR", "action": {"_unset": d}},
-                            {"file": "CHGCAR", "action": 
-                             {"_file_delete": {'mode': "actual"}}},
-                            {"file": "WAVECAR","action": 
-                             {"_file_delete": {'mode': "actual"}}}])
+                            {"file": "CHGCAR",
+                             "action": {"_file_delete": {'mode': "actual"}}},
+                            {"file": "WAVECAR",
+                             "action": {"_file_delete": {'mode': "actual"}}}])
+
+        if "pssyevx" in self.errors:
+            actions.append({"dict": "INCAR", "action":
+                                    {"_set": {"ALGO": "Normal"}}})
+        if "eddrmm" in self.errors:
+            #RMM algorithm is not stable for this calculation
+            if vi["INCAR"].get("ALGO", "Normal") in ["Fast", "VeryFast"]:
+                actions.append({"dict": "INCAR", "action":
+                                        {"_set": {"ALGO": "Normal"}}})
+            else:
+                potim = float(vi["INCAR"].get("POTIM", 0.5)) / 2.0
+                actions.append({"dict": "INCAR",
+                                "action": {"_set": {"POTIM": potim}}})
+
+            actions.append({"file": "CHGCAR",
+                            "action": {"_file_delete": {'mode': "actual"}}})
+            actions.append({"file": "WAVECAR",
+                            "action": {"_file_delete": {'mode': "actual"}}})
 
         VaspModder(vi=vi).apply_actions(actions)
         return {"errors": list(self.errors), "actions": actions}
@@ -269,14 +312,13 @@ class MeshSymmetryErrorHandler(ErrorHandler):
             # if symmetry is off
             if v.converged or (not v.incar.get('ISYM', True)):
                 return False
-            # do not apply if job was terminated (vasprun.xml cannot be read)
-            with open(self.output_filename, "r") as f:
-                for line in f:
-                    l = line.strip()
-                    if l.find(msg) != -1:
-                        return True
         except:
             pass
+        with open(self.output_filename, "r") as f:
+            for line in f:
+                l = line.strip()
+                if l.find(msg) != -1:
+                    return True
         return False
 
     def correct(self):
@@ -538,15 +580,15 @@ class NonConvergingErrorHandler(ErrorHandler):
                 #try linear mixing
                 backup(["INCAR", "KPOINTS", "POSCAR", "OUTCAR", "vasprun.xml"])
                 actions.append({"dict": "INCAR",
-                            "action": {"_set": {"AMIX": 0.1, "BMIX": 0.01,
-                                                "ICHARG": 2}}})
+                                "action": {"_set": {"AMIX": 0.1, "BMIX": 0.01,
+                                                    "ICHARG": 2}}})
 
             elif bmix < 3.0 and amin > 0.01:
                 #Try increasing bmix
                 backup(["INCAR", "KPOINTS", "POSCAR", "OUTCAR", "vasprun.xml"])
                 actions.append({"dict": "INCAR",
-                            "action": {"_set": {"AMIN": 0.01, "BMIX": 3.0,
-                                                "ICHARG": 2}}})
+                                "action": {"_set": {"AMIN": 0.01, "BMIX": 3.0,
+                                                    "ICHARG": 2}}})
 
         if actions:
             VaspModder(vi=vi).apply_actions(actions)
@@ -626,7 +668,7 @@ class WalltimeHandler(ErrorHandler):
                     o = Oszicar("OSZICAR")
                     nsteps = len(o.ionic_steps)
                     time_per_step = total_secs / nsteps
-                except Exception as ex:
+                except Exception:
                     time_per_step = 0
             else:
                 try:
